Changelog
=========

master
------

v0.1.4
------

- (`#7 <https://github.com/openscm/openscm-units/pull/7>`_) Added C7F16, C8F18 and SO2F2 AR5GWP100 (closes `#8 <https://github.com/openscm/openscm-units/issues/8>`_)

v0.1.3
------

- (`#7 <https://github.com/openscm/openscm-units/pull/7>`_) Include metric conversions data in package
- (`#6 <https://github.com/openscm/openscm-units/pull/6>`_) Add conda install instructions

v0.1.2
------

- (`#5 <https://github.com/openscm/openscm-units/pull/5>`_) Update ``MANIFEST.in`` to ensure ``LICENSE``, ``README.rst`` and ``CHANGELOG.rst`` are included in source distributions
- (`#4 <https://github.com/openscm/openscm-units/pull/4>`_) Update README and url to point to openscm organisation

v0.1.1
------

- (`#2 <https://github.com/openscm/openscm-units/pull/2>`_) Hotfix so that 'Tt' is terra tonne rather than 'tex'

v0.1.0
------

- (`#1 <https://github.com/openscm/openscm-units/pull/1>`_) Setup repository
